XBRL::JPFR::Branch
XBRL::JPFR::Branch - OO Module for Encapsulating XBRL::JPFR Branchs
SYNOPSIS
use XBRL::JPFR::Branch;
my $branch = XBRL::JPFR::Branch->new(XBRL::JPFR::Element);
DESCRIPTION
This module is part of the XBRL::JPFR modules group and is intended for use with XBRL::JPFR.
- new
-
Constructor for object takes the branch XML from the element.
- depth
-
Get or set the Branch's depth.
- order
-
Get or set the branch's order.
- weight
-
Get or set the branch's weight.
- label
-
Get or set the branch's label
- from_short
-
Get or set the branch's from_short
- from_full
-
Get or set the branch's from_full
- to_short
-
Get or set the branch's to_short.
- to_full
-
Get or set the branch's to_full.
- id_short
-
Get or set the branch's id_short.
- id_full
-
Get or set the branch's id_full.
- tos
-
Get or set the branch's children.
AUTHOR
Tetsuya Yamamoto <yonjouhan@gmail.com>
SEE ALSO
Modules: XBRL XBRL::JPFR
COPYRIGHT AND LICENSE
Copyright (C) 2015 by Tetsuya Yamamoto
This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself, either Perl version 5.10 or, at your option, any later version of Perl 5 you may have available.